@@ -1,18 +1,17 @@
 #!/usr/bin/env python
-import argparse
 import contextlib
-import pathlib
 import threading
 import time
 
+import configargparse
 import gi
 import mpd
 
 gi.require_version('Gtk', '3.0')
 
-from gi.repository import GLib, Gtk, Gdk, GdkPixbuf  # noqa: E402
+from gi.repository import Gio, GLib, Gtk, Gdk, GdkPixbuf  # noqa: E402
 
-version = '0.0.1'
+version = '0.0.4'
 
 
 @contextlib.contextmanager
@@ -34,62 +33,58 @@ def _mpd_client(*args, **kwargs):
         client.disconnect()
 
 
-def _find_song_art(library, song_path):
-    for path in library.joinpath(song_path).parent.iterdir():
-        if path.name in ('cover.jpg', 'cover.png'):
-            return path
-
-
-def app_main(mpd_host, mpd_port, library):
+def app_main(mpd_host, mpd_port):
     win = Gtk.Window(default_height=500, default_width=500)
-    win.connect("destroy", Gtk.main_quit)
+    win.connect('destroy', Gtk.main_quit)
 
     win.override_background_color(
         Gtk.StateType.NORMAL, Gdk.RGBA(red=0, green=0, blue=0))
 
-    vbox = Gtk.VBox()
-    win.add(vbox)
     image = Gtk.Image()
-    vbox.add(image)
-    image_path = None
+    pixbuf = None
+    win.add(image)
 
     def set_image():
-        if image_path is None:
-            image.clear()
-            return False
+        nonlocal pixbuf
 
-        win_width, win_height = win.get_size()
-        pixbuf = GdkPixbuf.Pixbuf.new_from_file(str(image_path))
-        aspect = (pixbuf.get_width() / pixbuf.get_height())
+        if pixbuf:
+            win_width, win_height = win.get_size()
+            aspect = (pixbuf.get_width() / pixbuf.get_height())
 
-        if aspect < 1:
-            height = win_height
-            width = aspect * height
-            if width > win_width:
-                height = (win_width / width) * height
-                width = win_width
-        else:
-            width = win_width
-            height = (1 / aspect) * width
-            if height > win_height:
-                width = (win_height / height) * width
+            if aspect < 1:
                 height = win_height
+                width = aspect * height
+                if width > win_width:
+                    height = (win_width / width) * height
+                    width = win_width
+            else:
+                width = win_width
+                height = (1 / aspect) * width
+                if height > win_height:
+                    width = (win_height / height) * width
+                    height = win_height
 
-        pixbuf = pixbuf.scale_simple(
-            width, height, GdkPixbuf.InterpType.BILINEAR)
-        image.set_from_pixbuf(pixbuf)
+            pixbuf = pixbuf.scale_simple(
+                width, height, GdkPixbuf.InterpType.BILINEAR)
+            image.set_from_pixbuf(pixbuf)
+        else:
+            image.clear()
         return False
 
     def mpd_loop():
-        nonlocal image_path
+        nonlocal pixbuf
 
         with _mpd_client(mpd_host, mpd_port) as client:
             while True:
                 current = client.currentsong()
                 if not current:
-                    image_path = None
+                    pixbuf = None
                 else:
-                    image_path = _find_song_art(library, current['file'])
+                    image_bytes = client.albumart(current['file'])
+                    pixbuf = GdkPixbuf.Pixbuf.new_from_stream(
+                        Gio.MemoryInputStream.new_from_bytes(
+                            GLib.Bytes.new(image_bytes)
+                        ), None)
                 GLib.idle_add(set_image)
                 client.idle()
 
@@ -98,7 +93,7 @@ def app_main(mpd_host, mpd_port, library):
     def _on_resize(*args):
         set_image()
 
-    win.connect("size-allocate", _on_resize)
+    win.connect('size-allocate', _on_resize)
 
     thread = threading.Thread(target=mpd_loop)
     thread.daemon = True
@@ -106,19 +101,20 @@ def app_main(mpd_host, mpd_port, library):
 
 
 def main():
-    parser = argparse.ArgumentParser()
+    parser = configargparse.ArgumentParser(
+        default_config_files=['~/.config/mpd-art-box/config'])
+    parser.add_argument('-c', '--config', is_config_file=True,
+                        help='config path')
     parser.add_argument('--host', default='localhost',
                         help='MPD host (default: %(default)s)')
     parser.add_argument('--port', type=int, default=6600,
                         help='MPD port (default: %(default)s)')
-    parser.add_argument('library', type=pathlib.Path,
-                        help='root path of the MPD library')
     parser.add_argument('--version', action='version', version=version)
     args = parser.parse_args()
 
-    app_main(args.host, args.port, args.library)
+    app_main(args.host, args.port)
     Gtk.main()
 
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     main()
